@@ -283,7 +283,8 @@ class PhoneNumberMatcherTest(TestMetadataTestCase):
 
         self.doTestFindInContext("64(0)64123456", "NZ")
         # Check that using a "/" is fine in a phone number.
-        self.doTestFindInContext("123/45678", "DE")
+        # Note that real Polish numbers do *not* start with a 0.
+        self.doTestFindInContext("0123/456789", "PL")
         self.doTestFindInContext("123-456-7890", "US")
 
     # See PhoneNumberUtilTest.testParseWithInternationalPrefixes().
@@ -418,34 +419,53 @@ class PhoneNumberMatcherTest(TestMetadataTestCase):
         for ii in range(8, 20):
             self.assertEqualRange(text, ii, 19, 28)
 
+    def testFourMatchesInARow(self):
+        number1 = "415-666-7777"
+        number2 = "800-443-1223"
+        number3 = "212-443-1223"
+        number4 = "650-443-1223"
+        text = number1 + " - " + number2 + " - " + number3 + " - " + number4
+
+        matcher = PhoneNumberMatcher(text, "US")
+        match = matcher.next() if matcher.has_next() else None
+        self.assertMatchProperties(match, text, number1, "US")
+
+        match = matcher.next() if matcher.has_next() else None
+        self.assertMatchProperties(match, text, number2, "US")
+
+        match = matcher.next() if matcher.has_next() else None
+        self.assertMatchProperties(match, text, number3, "US")
+
+        match = matcher.next() if matcher.has_next() else None
+        self.assertMatchProperties(match, text, number4, "US")
+
+    def testMatchesFoundWithMultipleSpaces(self):
+        number1 = "(415) 666-7777"
+        number2 = "(800) 443-1223"
+        text = number1 + " " + number2
+
+        matcher = PhoneNumberMatcher(text, "US")
+        match = matcher.next() if matcher.has_next() else None
+        self.assertMatchProperties(match, text, number1, "US")
+
+        match = matcher.next() if matcher.has_next() else None
+        self.assertMatchProperties(match, text, number2, "US")
+
     def testMatchWithSurroundingZipcodes(self):
         number = "415-666-7777"
         zipPreceding = "My address is CA 34215 - " + number + " is my number."
-        expectedResult = phonenumberutil.parse(number, "US")
 
         matcher = PhoneNumberMatcher(zipPreceding, "US")
-        if matcher.has_next():
-            match = matcher.next()
-        else:
-            match = None
-        self.assertTrue(match is not None,
-                        msg="Did not find a number in '" + zipPreceding + "'; expected " + number)
-        self.assertEqual(expectedResult, match.number)
-        self.assertEqual(number, match.raw_string)
+        match = matcher.next() if matcher.has_next() else None
+        self.assertMatchProperties(match, zipPreceding, number, "US")
 
         # Now repeat, but this time the phone number has spaces in it. It should still be found.
         number = "(415) 666 7777"
 
         zipFollowing = "My number is " + number + ". 34215 is my zip-code."
         matcher = PhoneNumberMatcher(zipFollowing, "US")
-        if matcher.has_next():
-            matchWithSpaces = matcher.next()
-        else:
-            matchWithSpaces = None
-        self.assertTrue(matchWithSpaces is not None,
-                        msg="Did not find a number in '" + zipFollowing + "'; expected " + number)
-        self.assertEqual(expectedResult, matchWithSpaces.number)
-        self.assertEqual(number, matchWithSpaces.raw_string)
+        match = matcher.next() if matcher.has_next() else None
+        self.assertMatchProperties(match, zipFollowing, number, "US")
 
     def testIsLatinLetter(self):
         self.assertTrue(PhoneNumberMatcher._is_latin_letter('c'))
@@ -599,10 +619,7 @@ class PhoneNumberMatcherTest(TestMetadataTestCase):
         wrongMatchFoundCount = 0
         for test in testCases:
             iterator = self.findNumbersForLeniency(test.rawString, test.region, leniency)
-            if iterator.has_next():
-                match = iterator.next()
-            else:
-                match = None
+            match = iterator.next() if iterator.has_next() else None
             if match is None:
                 noMatchFoundCount += 1
                 prnt("No match found in  %s for leniency: %s" % (test, leniency), file=sys.stderr)
@@ -617,10 +634,7 @@ class PhoneNumberMatcherTest(TestMetadataTestCase):
         matchFoundCount = 0
         for test in testCases:
             iterator = self.findNumbersForLeniency(test.rawString, test.region, leniency)
-            if iterator.has_next():
-                match = iterator.next()
-            else:
-                match = None
+            match = iterator.next() if iterator.has_next() else None
             if match is not None:
                 matchFoundCount += 1
                 prnt("Match found in %s for leniency: %s" % (test, leniency), file=sys.stderr)
@@ -830,6 +844,15 @@ class PhoneNumberMatcherTest(TestMetadataTestCase):
         self.assertEqual(end - index, match.end)
         self.assertEqual(sub[match.start:match.end], match.raw_string)
 
+    def assertMatchProperties(self, match, text, number, region):
+        """Asserts that the expected match is non-null, and that the raw string
+        and expected proto buffer are set appropriately."""
+        expectedResult = phonenumberutil.parse(number, region)
+        self.assertTrue(match is not None,
+                        msg="Did not find a number in '" + text + "'; expected " + number)
+        self.assertEqual(expectedResult, match.number)
+        self.assertEqual(number, match.raw_string)
+
     def doTestFindInContext(self, number, defaultCountry):
         """Tests numbers found by PhoneNumberMatcher in various textual contexts"""
         self.findPossibleInContext(number, defaultCountry)
@@ -893,10 +916,7 @@ class PhoneNumberMatcherTest(TestMetadataTestCase):
             end = start + len(number)
             matcher = PhoneNumberMatcher(text, defaultCountry, leniency, 65535)
 
-            if matcher.has_next():
-                match = matcher.next()
-            else:
-                match = None
+            match = matcher.next() if matcher.has_next() else None
             self.assertTrue(match is not None,
                             msg="Did not find a number in '" + text + "'; expected '" + number + "'")
 
@@ -934,8 +954,6 @@ class PhoneNumberMatcherTest(TestMetadataTestCase):
         # can't be used in a NumberTest).
         m0 = PhoneNumberMatcher(xx_ext, "US", leniency=Leniency.POSSIBLE).next()
         self.assertEqual(xx_ext, m0.raw_string)
-        m1 = PhoneNumberMatcher(xx_ext, "US", leniency=Leniency.VALID).next()
-        self.assertEqual("800 234 1 111", m1.raw_string)
         matcher2 = PhoneNumberMatcher(xx_ext, "US", leniency=Leniency.STRICT_GROUPING)
         self.assertFalse(matcher2.has_next())
 
